@@ -381,7 +381,7 @@ def slugify(s, delimiter='-'):
     """
     Normalize `s` into ASCII and replace non-word characters with `delimiter`.
     """
-    s = unicodedata.normalize('NFKD', u(s)).encode('ascii', 'ignore').decode('ascii')
+    s = unicodedata.normalize('NFKD', to_unicode(s)).encode('ascii', 'ignore').decode('ascii')
     return RE_SLUG.sub(delimiter, s).strip(delimiter).lower()
 
 
